@@ -1,6 +1,7 @@
 /* eslint-disable no-case-declarations */
 import { AnyAction } from "redux";
 import { CloudreveFile } from "../../types";
+import { Policy } from "../../component/Uploader/core/types";
 
 interface SelectProps {
     isMultiple: boolean;
@@ -35,6 +36,7 @@ export interface ExplorerState {
     keywords: string;
     fileSave: boolean;
     sideBarOpen: boolean;
+    currentPolicy?: Policy;
 }
 
 export const initState: ExplorerState = {
@@ -56,6 +58,8 @@ export const initState: ExplorerState = {
             size: 0,
             type: "file",
             date: "",
+            path: "",
+            create_date: "",
         },
         index: -1,
     },
@@ -67,6 +71,8 @@ export const initState: ExplorerState = {
             size: 0,
             type: "file",
             date: "",
+            path: "",
+            create_date: "",
         },
         other: [],
     },
@@ -77,6 +83,8 @@ export const initState: ExplorerState = {
             size: 0,
             type: "file",
             date: "",
+            path: "",
+            create_date: "",
         },
         other: [],
         playingName: null,
@@ -180,7 +188,7 @@ const explorer = (
                     other: state.fileList,
                 },
             });
-        case "AUDIO_PREVIEW_SET_IS_OPEN":            
+        case "AUDIO_PREVIEW_SET_IS_OPEN":
             return Object.assign({}, state, {
                 audioPreview: {
                     ...state.audioPreview,
@@ -231,6 +239,11 @@ const explorer = (
                 ...state,
                 sideBarOpen: action.open,
             };
+        case "SET_CURRENT_POLICY":
+            return {
+                ...state,
+                currentPolicy: action.policy,
+            };
         default:
             return state;
     }
