@@ -1,7 +1,6 @@
 package bootstrap
 
 import (
-	"embed"
 	model "github.com/cloudreve/Cloudreve/v3/models"
 	"github.com/cloudreve/Cloudreve/v3/models/scripts"
 	"github.com/cloudreve/Cloudreve/v3/pkg/aria2"
@@ -14,10 +13,11 @@ import (
 	"github.com/cloudreve/Cloudreve/v3/pkg/mq"
 	"github.com/cloudreve/Cloudreve/v3/pkg/task"
 	"github.com/gin-gonic/gin"
+	"io/fs"
 )
 
 // Init 初始化启动
-func Init(path string, statics embed.FS) {
+func Init(path string, statics fs.FS) {
 	InitApplication()
 	conf.Init(path)
 	// Debug 关闭时，切换为生产模式
