@@ -3,18 +3,10 @@ package filesystem
 import (
 	"errors"
 	"fmt"
-	"github.com/cloudreve/Cloudreve/v3/pkg/cluster"
-	"github.com/cloudreve/Cloudreve/v3/pkg/filesystem/driver"
-	"github.com/cloudreve/Cloudreve/v3/pkg/filesystem/driver/shadow/masterinslave"
-	"github.com/cloudreve/Cloudreve/v3/pkg/filesystem/driver/shadow/slaveinmaster"
-	"io"
-	"net/http"
-	"net/url"
-	"sync"
-
 	model "github.com/cloudreve/Cloudreve/v3/models"
-	"github.com/cloudreve/Cloudreve/v3/pkg/auth"
+	"github.com/cloudreve/Cloudreve/v3/pkg/cluster"
 	"github.com/cloudreve/Cloudreve/v3/pkg/conf"
+	"github.com/cloudreve/Cloudreve/v3/pkg/filesystem/driver"
 	"github.com/cloudreve/Cloudreve/v3/pkg/filesystem/driver/cos"
 	"github.com/cloudreve/Cloudreve/v3/pkg/filesystem/driver/local"
 	"github.com/cloudreve/Cloudreve/v3/pkg/filesystem/driver/onedrive"
@@ -22,11 +14,16 @@ import (
 	"github.com/cloudreve/Cloudreve/v3/pkg/filesystem/driver/qiniu"
 	"github.com/cloudreve/Cloudreve/v3/pkg/filesystem/driver/remote"
 	"github.com/cloudreve/Cloudreve/v3/pkg/filesystem/driver/s3"
+	"github.com/cloudreve/Cloudreve/v3/pkg/filesystem/driver/shadow/masterinslave"
+	"github.com/cloudreve/Cloudreve/v3/pkg/filesystem/driver/shadow/slaveinmaster"
 	"github.com/cloudreve/Cloudreve/v3/pkg/filesystem/driver/upyun"
 	"github.com/cloudreve/Cloudreve/v3/pkg/request"
 	"github.com/cloudreve/Cloudreve/v3/pkg/serializer"
 	"github.com/gin-gonic/gin"
 	cossdk "github.com/tencentyun/cos-go-sdk-v5"
+	"net/http"
+	"net/url"
+	"sync"
 )
 
 // FSPool 文件系统资源池
@@ -36,16 +33,6 @@ var FSPool = sync.Pool{
 	},
 }
 
-// FileHeader 上传来的文件数据处理器
-type FileHeader interface {
-	io.Reader
-	io.Closer
-	GetSize() uint64
-	GetMIMEType() string
-	GetFileName() string
-	GetVirtualPath() string
-}
-
 // FileSystem 管理文件的文件系统
 type FileSystem struct {
 	// 文件系统所有者
@@ -104,6 +91,8 @@ func (fs *FileSystem) reset() {
 func NewFileSystem(user *model.User) (*FileSystem, error) {
 	fs := getEmptyFS()
 	fs.User = user
+	fs.Policy = &fs.User.Policy
+
 	// 分配存储策略适配器
 	err := fs.DispatchHandler()
 
@@ -132,17 +121,11 @@ func NewAnonymousFileSystem() (*FileSystem, error) {
 
 // DispatchHandler 根据存储策略分配文件适配器
 func (fs *FileSystem) DispatchHandler() error {
-	var policyType string
-	var currentPolicy *model.Policy
-
 	if fs.Policy == nil {
-		// 如果没有具体指定，就是用用户当前存储策略
-		policyType = fs.User.Policy.Type
-		currentPolicy = &fs.User.Policy
-	} else {
-		policyType = fs.Policy.Type
-		currentPolicy = fs.Policy
+		return errors.New("未设置存储策略")
 	}
+	policyType := fs.Policy.Type
+	currentPolicy := fs.Policy
 
 	switch policyType {
 	case "mock", "anonymous":
@@ -153,23 +136,19 @@ func (fs *FileSystem) DispatchHandler() error {
 		}
 		return nil
 	case "remote":
-		fs.Handler = remote.Driver{
-			Policy:       currentPolicy,
-			Client:       request.NewClient(),
-			AuthInstance: auth.HMACAuth{[]byte(currentPolicy.SecretKey)},
+		handler, err := remote.NewDriver(currentPolicy)
+		if err != nil {
+			return err
 		}
-		return nil
+
+		fs.Handler = handler
 	case "qiniu":
-		fs.Handler = qiniu.Driver{
-			Policy: currentPolicy,
-		}
+		fs.Handler = qiniu.NewDriver(currentPolicy)
 		return nil
 	case "oss":
-		fs.Handler = oss.Driver{
-			Policy:     currentPolicy,
-			HTTPClient: request.NewClient(),
-		}
-		return nil
+		handler, err := oss.NewDriver(currentPolicy)
+		fs.Handler = handler
+		return err
 	case "upyun":
 		fs.Handler = upyun.Driver{
 			Policy: currentPolicy,
@@ -194,13 +173,14 @@ func (fs *FileSystem) DispatchHandler() error {
 		}
 		return nil
 	case "s3":
-		fs.Handler = s3.Driver{
-			Policy: currentPolicy,
-		}
-		return nil
+		handler, err := s3.NewDriver(currentPolicy)
+		fs.Handler = handler
+		return err
 	default:
 		return ErrUnknownPolicyType
 	}
+
+	return nil
 }
 
 // NewFileSystemFromContext 从gin.Context创建文件系统
@@ -221,19 +201,14 @@ func NewFileSystemFromCallback(c *gin.Context) (*FileSystem, error) {
 	}
 
 	// 获取回调会话
-	callbackSessionRaw, ok := c.Get("callbackSession")
+	callbackSessionRaw, ok := c.Get(UploadSessionCtx)
 	if !ok {
 		return nil, errors.New("找不到回调会话")
 	}
 	callbackSession := callbackSessionRaw.(*serializer.UploadSession)
 
 	// 重新指向上传策略
-	policy, err := model.GetPolicyByID(callbackSession.PolicyID)
-	if err != nil {
-		return nil, err
-	}
-	fs.Policy = &policy
-	fs.User.Policy = policy
+	fs.Policy = &callbackSession.Policy
 	err = fs.DispatchHandler()
 
 	return fs, err
@@ -241,7 +216,7 @@ func NewFileSystemFromCallback(c *gin.Context) (*FileSystem, error) {
 
 // SwitchToSlaveHandler 将负责上传的 Handler 切换为从机节点
 func (fs *FileSystem) SwitchToSlaveHandler(node cluster.Node) {
-	fs.Handler = slaveinmaster.NewDriver(node, fs.Handler, &fs.User.Policy)
+	fs.Handler = slaveinmaster.NewDriver(node, fs.Handler, fs.Policy)
 }
 
 // SwitchToShadowHandler 将负责上传的 Handler 切换为从机节点转存使用的影子处理器
