@@ -5,16 +5,15 @@ import "encoding/json"
 // RequestRawSign 待签名的HTTP请求
 type RequestRawSign struct {
 	Path   string
-	Policy string
+	Header string
 	Body   string
 }
 
 // NewRequestSignString 返回JSON格式的待签名字符串
-// TODO 测试
-func NewRequestSignString(path, policy, body string) string {
+func NewRequestSignString(path, header, body string) string {
 	req := RequestRawSign{
 		Path:   path,
-		Policy: policy,
+		Header: header,
 		Body:   body,
 	}
 	res, _ := json.Marshal(req)
